weavenn
=======

k-NN graph construction algorithm using a locally varying similarity function.

```
pip install weavenn
```

```python
from weavenn import WeaveNN


clusterer = WeaveNN()
y = clusterer.fit_predict(X)
```


See the examples folder for usage.


